# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog, and this project adheres to Semantic Versioning.

## [0.1.0] - 2023-06-09

### Added

- `readme.md`
- `plugin.py`
- Support for `Mermaid` diagrams

[0.1.0]: https://gitlab.com/cfpt-mkdocs-plugins/mkdocs-table-of-figures/-/releases/v0.1.0